from starlette.request import Request
from starlette.response import Response


def asgi_application(func):
    def app(scope):
        async def awaitable(receive, send):
            request = Request(scope, receive)
            response = func(request)
            assert isinstance(response, Response)
            await response(receive, send)

        return awaitable

    return app



from starlette.decorators import asgi_application
from starlette.response import HTMLResponse, JSONResponse, Response, StreamingResponse
from starlette.request import Request
from starlette.testclient import TestClient


__all__ = (
    "asgi_application",
    "HTMLResponse",
    "JSONResponse",
    "Response",
    "StreamingResponse",
    "Request",
    "TestClient",
)
__version__ = "0.1.2"
